@@ -45,6 +45,7 @@
 #include "base/path.h"
 #include "base/settingvalue.h"
 #include "base/types.h"
+#include "base/utils/thread.h"
 #include "addtorrentparams.h"
 #include "cachestatus.h"
 #include "categoryoptions.h"
@@ -375,9 +376,6 @@ namespace BitTorrent
         Torrent *findTorrent(const InfoHash &infoHash) const override;
         QVector<Torrent *> torrents() const override;
         qsizetype torrentsCount() const override;
-        bool hasActiveTorrents() const override;
-        bool hasUnfinishedTorrents() const override;
-        bool hasRunningSeed() const override;
         const SessionStatus &status() const override;
         const CacheStatus &cacheStatus() const override;
         bool isListening() const override;
@@ -495,9 +493,7 @@ namespace BitTorrent
         lt::settings_pack loadLTSettings() const;
         void applyNetworkInterfacesSettings(lt::settings_pack &settingsPack) const;
         void configurePeerClasses();
-        int adjustLimit(int limit) const;
         void initMetrics();
-        void adjustLimits();
         void applyBandwidthLimits();
         void processBannedIPs(lt::ip_filter &filter);
         QStringList getListeningIPs() const;
@@ -697,7 +693,6 @@ namespace BitTorrent
         const bool m_wasPexEnabled = m_isPeXEnabled;
 
         int m_numResumeData = 0;
-        int m_extraLimit = 0;
         QVector<TrackerEntry> m_additionalTrackerList;
         QVector<TrackerEntry> m_publicTrackerList;
         QVector<QRegularExpression> m_excludedFileNamesRegExpList;
@@ -717,7 +712,7 @@ namespace BitTorrent
         // Tracker
         QPointer<Tracker> m_tracker;
 
-        QThread *m_ioThread = nullptr;
+        Utils::Thread::UniquePtr m_ioThread;
         ResumeDataStorage *m_resumeDataStorage = nullptr;
         FileSearcher *m_fileSearcher = nullptr;
 
