@@ -30,11 +30,13 @@
 
 #include <QWidget>
 
+#include "base/path.h"
+
 namespace Private
 {
     class FileComboEdit;
-    class FileEditorWithCompletion;
     class FileLineEdit;
+    class IFileEditorWithCompletion;
 }
 
 /*!
@@ -44,11 +46,15 @@ namespace Private
 class FileSystemPathEdit : public QWidget
 {
     Q_OBJECT
+    Q_DISABLE_COPY_MOVE(FileSystemPathEdit)
+
     Q_PROPERTY(Mode mode READ mode WRITE setMode)
-    Q_PROPERTY(QString selectedPath READ selectedPath WRITE setSelectedPath NOTIFY selectedPathChanged)
+    Q_PROPERTY(Path selectedPath READ selectedPath WRITE setSelectedPath NOTIFY selectedPathChanged)
     Q_PROPERTY(QString fileNameFilter READ fileNameFilter WRITE setFileNameFilter)
     Q_PROPERTY(QString dialogCaption READ dialogCaption WRITE setDialogCaption)
 
+    class FileSystemPathEditPrivate;
+
 public:
     ~FileSystemPathEdit() override;
 
@@ -64,15 +70,14 @@ public:
     Mode mode() const;
     void setMode(Mode mode);
 
-    QString currentDirectory() const;
-    QString selectedPath() const;
-    void setSelectedPath(const QString &val);
+    Path selectedPath() const;
+    void setSelectedPath(const Path &val);
 
     QString fileNameFilter() const;
     void setFileNameFilter(const QString &val);
 
-    QString placeholder() const;
-    void setPlaceholder(const QString &val);
+    Path placeholder() const;
+    void setPlaceholder(const Path &val);
 
     /// The browse button caption is "..." if true, and "Browse" otherwise
     bool briefBrowseButtonCaption() const;
@@ -84,10 +89,10 @@ public:
     virtual void clear() = 0;
 
 signals:
-    void selectedPathChanged(const QString &path);
+    void selectedPathChanged(const Path &path);
 
 protected:
-    explicit FileSystemPathEdit(Private::FileEditorWithCompletion *editor, QWidget *parent);
+    explicit FileSystemPathEdit(Private::IFileEditorWithCompletion *editor, QWidget *parent);
 
     template <class Widget>
     Widget *editWidget() const
@@ -99,14 +104,14 @@ protected slots:
     void onPathEdited();
 
 private:
+    Q_DECLARE_PRIVATE(FileSystemPathEdit)
+
     virtual QString editWidgetText() const = 0;
     virtual void setEditWidgetText(const QString &text) = 0;
 
     QWidget *editWidgetImpl() const;
-    Q_DISABLE_COPY_MOVE(FileSystemPathEdit)
-    class FileSystemPathEditPrivate;
-    Q_DECLARE_PRIVATE(FileSystemPathEdit)
-    FileSystemPathEditPrivate *d_ptr;
+
+    FileSystemPathEditPrivate *d_ptr = nullptr;
 };
 
 /// Widget which uses QLineEdit for path editing
@@ -137,9 +142,9 @@ public:
     void clear() override;
 
     int count() const;
-    QString item(int index) const;
-    void addItem(const QString &text);
-    void insertItem(int index, const QString &text);
+    Path item(int index) const;
+    void addItem(const Path &path);
+    void insertItem(int index, const Path &path);
 
     int currentIndex() const;
     void setCurrentIndex(int index);
