@@ -94,7 +94,7 @@ void AppController::shutdownAction()
     // Special handling for shutdown, we
     // need to reply to the Web UI before
     // actually shutting down.
-    QTimer::singleShot(100ms, qApp, []()
+    QTimer::singleShot(100ms, Qt::CoarseTimer, qApp, []
     {
         QCoreApplication::exit();
     });
@@ -107,6 +107,19 @@ void AppController::preferencesAction()
 
     QJsonObject data;
 
+    // Behavior
+    // Language
+    data[u"locale"_qs] = pref->getLocale();
+    data[u"performance_warning"_qs] = session->isPerformanceWarningEnabled();
+    // Log file
+    data[u"file_log_enabled"_qs] = app()->isFileLoggerEnabled();
+    data[u"file_log_path"_qs] = app()->fileLoggerPath().toString();
+    data[u"file_log_backup_enabled"_qs] = app()->isFileLoggerBackup();
+    data[u"file_log_max_size"_qs] = app()->fileLoggerMaxSize() / 1024;
+    data[u"file_log_delete_old"_qs] = app()->isFileLoggerDeleteOld();
+    data[u"file_log_age"_qs] = app()->fileLoggerAge();
+    data[u"file_log_age_type"_qs] = app()->fileLoggerAgeType();
+
     // Downloads
     // When adding a torrent
     data[u"torrent_content_layout"_qs] = Utils::String::fromEnum(session->torrentContentLayout());
@@ -251,9 +264,6 @@ void AppController::preferencesAction()
     data[u"public_trackers"_qs] = session->publicTrackers();
 
     // Web UI
-    // Language
-    data[u"locale"_qs] = pref->getLocale();
-    data[u"performance_warning"_qs] = session->isPerformanceWarningEnabled();
     // HTTP Server
     data[u"web_ui_domain_list"_qs] = pref->getServerDomains();
     data[u"web_ui_address"_qs] = pref->getWebUiAddress();
@@ -304,6 +314,8 @@ void AppController::preferencesAction()
 
     // Advanced settings
     // qBitorrent preferences
+    // Resume data storage type
+    data[u"resume_data_storage_type"_qs] = Utils::String::fromEnum(session->resumeDataStorageType());
     // Physical memory (RAM) usage limit
     data[u"memory_working_set_limit"_qs] = app()->memoryWorkingSetLimit();
     // Current network interface
@@ -413,6 +425,45 @@ void AppController::setPreferencesAction()
         return (it != m.constEnd());
     };
 
+    // Behavior
+    // Language
+    if (hasKey(u"locale"_qs))
+    {
+        QString locale = it.value().toString();
+        if (pref->getLocale() != locale)
+        {
+            auto *translator = new QTranslator;
+            if (translator->load(u":/lang/qbittorrent_"_qs + locale))
+            {
+                qDebug("%s locale recognized, using translation.", qUtf8Printable(locale));
+            }
+            else
+            {
+                qDebug("%s locale unrecognized, using default (en).", qUtf8Printable(locale));
+            }
+            qApp->installTranslator(translator);
+
+            pref->setLocale(locale);
+        }
+    }
+    if (hasKey(u"performance_warning"_qs))
+        session->setPerformanceWarningEnabled(it.value().toBool());
+    // Log file
+    if (hasKey(u"file_log_enabled"_qs))
+        app()->setFileLoggerEnabled(it.value().toBool());
+    if (hasKey(u"file_log_path"_qs))
+        app()->setFileLoggerPath(Path(it.value().toString()));
+    if (hasKey(u"file_log_backup_enabled"_qs))
+        app()->setFileLoggerBackup(it.value().toBool());
+    if (hasKey(u"file_log_max_size"_qs))
+        app()->setFileLoggerMaxSize(it.value().toInt() * 1024);
+    if (hasKey(u"file_log_delete_old"_qs))
+        app()->setFileLoggerDeleteOld(it.value().toBool());
+    if (hasKey(u"file_log_age"_qs))
+        app()->setFileLoggerAge(it.value().toInt());
+    if (hasKey(u"file_log_age_type"_qs))
+        app()->setFileLoggerAgeType(it.value().toInt());
+
     // Downloads
     // When adding a torrent
     if (hasKey(u"torrent_content_layout"_qs))
@@ -681,28 +732,6 @@ void AppController::setPreferencesAction()
         pref->setCustomizeTrackersListUrl(it.value().toString());
 
     // Web UI
-    // Language
-    if (hasKey(u"locale"_qs))
-    {
-        QString locale = it.value().toString();
-        if (pref->getLocale() != locale)
-        {
-            auto *translator = new QTranslator;
-            if (translator->load(u":/lang/qbittorrent_"_qs + locale))
-            {
-                qDebug("%s locale recognized, using translation.", qUtf8Printable(locale));
-            }
-            else
-            {
-                qDebug("%s locale unrecognized, using default (en).", qUtf8Printable(locale));
-            }
-            qApp->installTranslator(translator);
-
-            pref->setLocale(locale);
-        }
-    }
-    if (hasKey(u"performance_warning"_qs))
-        session->setPerformanceWarningEnabled(it.value().toBool());
     // HTTP Server
     if (hasKey(u"web_ui_domain_list"_qs))
         pref->setServerDomains(it.value().toString());
@@ -789,6 +818,9 @@ void AppController::setPreferencesAction()
 
     // Advanced settings
     // qBittorrent preferences
+    // Resume data storage type
+    if (hasKey(u"resume_data_storage_type"_qs))
+        session->setResumeDataStorageType(Utils::String::toEnum(it.value().toString(), BitTorrent::ResumeDataStorageType::Legacy));
     // Physical memory (RAM) usage limit
     if (hasKey(u"memory_working_set_limit"_qs))
         app()->setMemoryWorkingSetLimit(it.value().toInt());
